import maya.cmds as cmds

# Store the original values of film offsets and focal length
originalFilmOffsetH = 0.0
originalFilmOffsetV = 0.0
originalFocalLength = 0.0

def updateFilmOffsetH(value):
    currentCamera = cmds.modelEditor(cmds.getPanel(withFocus=True), q=True, camera=True)
    filmOffsetH = cmds.floatField("filmOffsetHField", q=True, value=True)
    filmOffsetH += value
    cmds.floatField("filmOffsetHField", e=True, value=filmOffsetH)
    cmds.setAttr(currentCamera + ".horizontalFilmOffset", filmOffsetH)

def updateFilmOffsetV(value):
    currentCamera = cmds.modelEditor(cmds.getPanel(withFocus=True), q=True, camera=True)
    filmOffsetV = cmds.floatField("filmOffsetVField", q=True, value=True)
    filmOffsetV += value
    cmds.floatField("filmOffsetVField", e=True, value=filmOffsetV)
    cmds.setAttr(currentCamera + ".verticalFilmOffset", filmOffsetV)

def updateFocalLength(value):
    currentCamera = cmds.modelEditor(cmds.getPanel(withFocus=True), q=True, camera=True)
    if value >= 2.5:
        cmds.setAttr(currentCamera + ".focalLength", value)
    else:
        cmds.setAttr(currentCamera + ".focalLength", 2.5)

def resetCameraSettings(*args):
    currentCamera = cmds.modelEditor(cmds.getPanel(withFocus=True), q=True, camera=True)
    cmds.setAttr(currentCamera + ".horizontalFilmOffset", originalFilmOffsetH)
    cmds.setAttr(currentCamera + ".verticalFilmOffset", originalFilmOffsetV)
    cmds.setAttr(currentCamera + ".focalLength", originalFocalLength)

    # Update the input windows and focal length slider
    cmds.floatField("filmOffsetHField", e=True, value=originalFilmOffsetH)
    cmds.floatField("filmOffsetVField", e=True, value=originalFilmOffsetV)
    cmds.floatSliderGrp("focalLengthSlider", e=True, value=originalFocalLength)

def createCameraSettingsUI():
    if cmds.window("cameraSettingsUI", exists=True):
        cmds.deleteUI("cameraSettingsUI")

    cmds.window("cameraSettingsUI", title="Camera Settings", resizeToFitChildren=True)

    cmds.columnLayout(adjustableColumn=True)

    currentCamera = cmds.modelEditor(cmds.getPanel(withFocus=True), q=True, camera=True)
    filmOffsetH = cmds.getAttr(currentCamera + ".horizontalFilmOffset")
    filmOffsetV = cmds.getAttr(currentCamera + ".verticalFilmOffset")
    currentFocalLength = cmds.getAttr(currentCamera + ".focalLength")

    # Store the original values
    global originalFilmOffsetH, originalFilmOffsetV, originalFocalLength
    originalFilmOffsetH = filmOffsetH
    originalFilmOffsetV = filmOffsetV
    originalFocalLength = currentFocalLength

    cmds.rowLayout(numberOfColumns=4)

    cmds.button(label="<<", width=50, command=lambda x: updateFilmOffsetH(-0.1))
    cmds.button(label=">>", width=50, command=lambda x: updateFilmOffsetH(0.1))
    filmOffsetHField = cmds.floatField("filmOffsetHField", value=filmOffsetH, precision=2, editable=True)
    cmds.floatField(filmOffsetHField, e=True, enterCommand=lambda x: updateFilmOffsetH(0.0))

    cmds.setParent("..")

    cmds.rowLayout(numberOfColumns=4)

    cmds.button(label="^", width=50, command=lambda x: updateFilmOffsetV(0.1))
    cmds.button(label="v", width=50, command=lambda x: updateFilmOffsetV(-0.1))
    filmOffsetVField = cmds.floatField("filmOffsetVField", value=filmOffsetV, precision=2, editable=True)
    cmds.floatField(filmOffsetVField, e=True, enterCommand=lambda x: updateFilmOffsetV(0.0))

    cmds.setParent("..")

    cmds.separator(height=10, style="none")

    cmds.text(label="Focal Length: {}".format(currentFocalLength))

    cmds.floatSliderGrp("focalLengthSlider", label="Focal Length", field=True, minValue=2.5, maxValue=180.0,
                        fieldMinValue=2.5, fieldMaxValue=1000.0, value=currentFocalLength, cc=updateFocalLength)

    cmds.button(label="Reset", command=resetCameraSettings)

    cmds.showWindow("cameraSettingsUI")

createCameraSettingsUI()
